@@ -1,3 +1,8 @@
+import logging
+import traceback
+from typing import Annotated
+
+import pydantic
 from bson import ObjectId, errors
 import rsa
 
@@ -26,6 +31,7 @@ class ObjectIdStr(str):
             return False
         return True
 
+
 class EncryptedStr(str):
     @classmethod
     def __get_validators__(cls):
@@ -33,16 +39,20 @@ class EncryptedStr(str):
 
     @classmethod
     def validate(cls, v):
-        return str(v)
+        return EncryptedStr(v)
 
     def encrypt(self, public_key):
         try:
             return rsa.encrypt(self.encode('utf-8'), public_key)
-        except (AttributeError, rsa.pkcs1.CryptoError):
+        except (AttributeError, rsa.pkcs1.CryptoError) as e:
+            logging.error(e)
+            logging.error(traceback.format_exc())
             raise RSAError()
 
     def decrypt(self, private_key):
         try:
             return rsa.decrypt(self.encode('utf-8'), private_key).decode('utf-8')
-        except (AttributeError, rsa.pkcs1.CryptoError):
-            raise RSAError()
\ No newline at end of file
+        except (AttributeError, rsa.pkcs1.CryptoError) as e:
+            logging.error(e)
+            logging.error(traceback.format_exc())
+            raise RSAError()
